#******************************************************************************
#
# Project ICI-Covid
#
# Obj: create variables
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 24/02/2021
#
#******************************************************************************


## Packages for the program
  # NB : for first run, need to do "install.packages(NAMEOFTHEPACKAGE)" first
  # Then, run library(PACKAGE) at each opening of R

# --> No package indicated here

#### Variable creation ####

attach(seniors)
                # mention the data frame we are going to use by default in the script
                    # "seniors" if you just run 0.Data
                
## Age/sex
age<-tcdagesen_c
moinsde76<-ifelse(59 < age & age <76,1,0)
de76a85<-ifelse(age >75 & age<86,1,0)
de86a90<-ifelse(age > 85 & age < 91,1,0)
de91a95<-ifelse(age > 90 & age < 96,1,0)
plusde96<-ifelse(age > 95,1,0)
  summary(moinsde76) 

sexe<-tcsexesen
femme<-c(sexe-1)

## Family 

nbenfant<-tcenf
enfant<-ifelse(nbenfant!=0,1,0)
enfant[is.na(enfant)]=0       #missing values recoded to 0
nbenfant[is.na(nbenfant)] <- 0
  summary(nbenfant) 
  summary(enfant) 
pasdenfant<-ifelse(enfant==0,1,0)

samecity<-ifelse(enfants$tcenfdom==2|enfants$tcenfdom==1,1,0)
enfants<- enfants %>% mutate(enfants,samecity)
enfants2 <- enfants %>% group_by(idsenior) %>% summarise(sum(samecity))
dummycity <- ifelse(enfants2$`sum(samecity)`>0,1,0)
enfants3<- enfants2 %>% mutate(enfants2,dummycity)

final<- left_join(seniors, enfants3, by = 'idsenior')
final$dummycity[is.na(final$dummycity)]=0

enfantdanslaville<-ifelse(final$dummycity==1,1,0)
enfantdanslaville[is.na(enfantdanslaville)]=0
enfantpasdanslaville<-ifelse(enfant==1 & dummycity==0,1,0)
  table(pasdenfant)
  table(enfantpasdanslaville)
  table(enfantdanslaville)

nbfrsoeur<-tcfrere+tcsoeur
  summary(nbfrsoeur) 

frere<-c("")
frere[tcfrere!=0]<-1
frere[frere== ""]<-0
frere[is.na(frere)]<-0        # NA = no brother

soeur<-c("")
soeur[tcsoeur!=0]<-1
soeur[soeur== ""]<-0
soeur[is.na(soeur)]<-0

freresoeur<-ifelse(frere!=0 | soeur!=0,1,0)

conjoint<-tccouple
conjoint[conjoint==9]<-0

avecconjoint<-ifelse(tcetabcj==1,1,0)
sexeconjoint<-c(tcsexecj-1)

classeconjoint<-ifelse(conjoint==0,"clibataire",
                       ifelse(tcetabcj==3,"conjoint  domicile","conjoint en institution"))
classeconjoint[is.na(classeconjoint)]<-"clibataire"
table(classeconjoint)

conjoint_1<-ifelse(classeconjoint=="clibataire",1,0)
conjoint_2<-ifelse(classeconjoint=="conjoint  domicile",1,0)
conjoint_3<-ifelse(classeconjoint=="conjoint en institution",1,0)


## Health

sante<-sdsante
santesubj<-ifelse(sante==1 | sante==2 | sante ==3,1,0)
table(santesubj)

## Alzheimer dummy

alzheimer<-ifelse(sdmala17==1,1,0)
alzheimer[is.na(alzheimer)]<-0


## ADL

toilette<-ifelse(ratoi!=1,1,0) ## se laver seul
habillage<-ifelse(rahab!=1,1,0) ## s'habiler/se dshabiller
nourriture<-ifelse(ranou!=1,1,0) ## couper sa nourriture, se servir  boire
manger<-ifelse(raman!=1,1,0) ## manger/boire seul une fois la nourriture prte
besoins<-ifelse(raeli!=1,1,0) ## se servir des toilettes
mobilite<-ifelse(racou!=1 | raass!=1,1,0) ## se lever/ s'assoir ou se coucher 

allerwc<-ifelse(lfsel!=1,1,0) ##contrle urine/selles

nbadl<-toilette+habillage+nourriture+manger+besoins+mobilite

ADL_worst<-ifelse(raman == 4 | raman==5 | raeli== 4 | raeli == 5 | raass == 4,1,0)

nbadl_any<-ifelse(nbadl>0,1,0)


## IADL

menage<-ifelse(ramen!=1,1,0)
administratif<-ifelse(raadm!=1,1,0)
courses<-ifelse(raach!=1,1,0)
prepnourriture<-ifelse(rarep!=1,1,0)
medicaments<-ifelse(ramed!=1,1,0)
telephone<-ifelse(ratel!=1,1,0)
sedeplacer<-ifelse(radpi!=1,1,0) 
sortirseul<-ifelse(radpe!=1,1,0)
transportcommun<-ifelse(rabus!=1,1,0)
trouverchemin<-ifelse(raori!=1,1,0)

nbiadl<-c(administratif+telephone+sedeplacer+sortirseul+transportcommun+trouverchemin)
table(nbiadl)

nbiadl_any<-ifelse(nbiadl>0,1,0)

## Disability group

Groupe<-ifelse(ADL_worst==1 & ((nbadl!=0 & nbiadl!=0) | (nbadl!=0 & nbiadl==0)),Groupe<-"Svrement dpendant",
               ifelse( (nbadl==0 & nbiadl==0) | (nbiadl>=1 & nbadl==0), Groupe<-"Pas de ADL","2 types de restriction"))
group_3<-ifelse(Groupe=="Svrement dpendant",1,0)
group_2<-ifelse(Groupe=="2 types de restriction",1,0)
group_1<-ifelse(Groupe=="Pas de ADL",1,0)

dependant<-ifelse(Groupe=="2 types de restriction" | Groupe=="Svrement dpendant",1,0)

## Socio-demographic characteristics

etude<-tcdiplom


nivetude<-ifelse(etude>6 & etude<98,"bac ou suprieur",
                 ifelse(etude==1,"aucun diplome","certificat d'tude/BEP/CAP"))

bacouplus<-ifelse(etude>6 & etude<98,1,0)
aucundiplome<-ifelse(etude==1,1,0)
certificatbepcap<-ifelse(etude==2 | etude==3 |etude==4 |etude==5 | etude==6,1,0)


## Informal care

aideproche<-aidentvq_c
aideouinon<-ifelse(aideproche==1,"oui","non")

## Additional variables 

raaident_r1  <- raaident_r1
raaident_r2  <- raaident_r2
raaident_r3  <- raaident_r3
raaident_r4  <- raaident_r4
raaident_r5  <- raaident_r5
raaident_r6  <- raaident_r6
raaident_r7  <- raaident_r7
raaident_r8  <- raaident_r8
raaident_r9  <- raaident_r9
raaident_r10 <- raaident_r10
raaident_r11 <- raaident_r11
raaident_r12 <- raaident_r12
raaident_r13 <- raaident_r13

aideproche_v2 <- ifelse(raaident_r1== 1 | raaident_r2== 1 | raaident_r3== 1 | raaident_r4== 1 | raaident_r5== 1 |
                          raaident_r6== 1 |raaident_r7== 1 | raaident_r8== 1 | raaident_r9== 1 |
                          raaident_r10== 1 | raaident_r11== 1 | raaident_r12== 1 | raaident_r13== 1, 1,0)

## Characteristics of the facility 

statutetab<-statut_etab
lucratif<-ifelse(statutetab=="Prive_Lucr",1,0)
lucratif_no<-ifelse(statutetab=="Prive_Non_Lucr",1,0)
public_hosp<-ifelse(statutetab=="Public_hosp",1,0)
public_hosp_no<-ifelse(statutetab=="Public_non_hosp",1,0)

  #IDT <- seniors %>% group_by(idetab) %>% filter(row_number()==1) #PB

taille<-ifelse(capacite_installee<60,"Petit",
               ifelse(capacite_installee<100 &capacite_installee>59,"Moyen",
                      ifelse(capacite_installee>99,"Grand", "non renseign")))
taille[is.na(capacite_installee)]<-"non renseign"
  # MT: there was an issue here, as the code was: taille[is.na(taille)]<-"Non renseign"
  # it recoded taille = non renseigne for everyone

taille_1<-ifelse(taille=="Petit",1,0)
taille_2<-ifelse(taille=="Moyen",1,0)
taille_3<-ifelse(taille=="Grand",1,0)
taille_4<-ifelse(taille=="non renseign",1,0)

etab<-ifelse(categ_code_r==500,etab<-"EHPAD",
             ifelse(categ_code_r==362,etab<-"SLD",etab<-"tablissement d'hbergement"))

etab_1<-ifelse(etab=="EHPAD",1,0)
etab_2<-ifelse(etab=="SLD",1,0)
etab_3<-ifelse(etab=="tablissement d'hbergement",1,0)

## Weights

poidsen<-as.numeric(as.character(seniors$poids_senior))


#### Dataframes creation ####

#Create a dataset with the variables that will be used for the descriptive statistics table
data_clean <- as.data.frame(
  cbind(femme,moinsde76,de76a85,de86a90,de91a95,plusde96,aucundiplome,certificatbepcap,
        bacouplus,conjoint_1,conjoint_2,conjoint_3,enfant,nbenfant,pasdenfant,enfantdanslaville,enfantpasdanslaville,freresoeur,
        nbiadl_any,nbiadl,nbadl_any,nbadl,group_1,group_2,group_3,alzheimer,santesubj,
        etab_1,etab_2,etab_3,lucratif,lucratif_no,public_hosp,public_hosp_no,
        taille_1,taille_2,taille_3,taille_4,raaident_r1,raaident_r2,raaident_r3,raaident_r4,raaident_r5,
        raaident_r6,raaident_r7,raaident_r8,raaident_r9,raaident_r10,raaident_r11,
        raaident_r12,raaident_r13,poidsen)
)

#Create a dataset with the variables that will be used for the regressions
data_regression <- as.data.frame(
  cbind(idetab,idsenior,poidsen,aideproche_v2,
        moinsde76,de76a85,de91a95,plusde96,femme,conjoint_1,conjoint_2,
        Groupe,aucundiplome,bacouplus,alzheimer,santesubj,pasdenfant,enfantdanslaville,enfantpasdanslaville,freresoeur,lucratif)
)




