#******************************************************************************
#
# Project ICI-Covid
#
# Obj: Spider charts of
#         Share of individuals with ADL restriction (Figure 1)
#         Share of individuals with iADL restriction (Figure 2)
#         Share of individuals helped with a task (Figure 4)
#         Share of individuals helped with a task by gender (additional figure)
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 17/04/2021
#
#******************************************************************************


#### Packages for the program ####

# NB : for first run, need to do "install.packages(NAMEOFTHEPACKAGE)" first
# Then, run library(PACKAGE) at each opening of R

library(questionr)
  #wtd.table
library(fmsb)
library(haven)
library(foreign)
library(Hmisc)
library(dplyr)
library(tidyr)
library(readxl)

#Paths are defined in 0.Data.R



#### Spider charts: being helped with ADL or IADL ####
#####################################################

#### ADL ####

data<-read_xlsx(paste0(dropbox, out_DS ,"ICI-Covid_Figure1_Restrictions_ADL.xlsx"))
data <- as.data.frame(data)

#Transpose
data <- t(data)
data <- as.data.frame(data)

#Keep proportion being help with a given task
data <- data %>%
  slice(3:3)

colnames(data) <- c("ADL: dress", "ADL: groom", "ADL: cut food", "ADL: eat", 
                    "ADL: use toilets","ADL: transfer")
                   
## add 2 lines to the dataframe: the max and min of each topic to show on the plot
data <- rbind(rep(1,6) , rep(0,6) , data)

#Convert to numeric values
data = data %>% mutate_all(as.numeric)

## Export the radar chart
png(filename = paste0(dropbox, out_Fig, "ICI-Covid_Figure1_Restrictions_ADL.png"))

radarchart( data  , axistype=1, 
            
            #custom polygon
            pcol=rgb(0.5,0.5,0.5,1) , pfcol=rgb(0.5,0.5,0.5,0.5) , plwd=4 , 
            
            #custom the grid
            cglcol="grey", cglty=1, axislabcol="grey", cglwd=0.8,
            
            #custom labels
            vlcex=1.4
)

dev.off()

#### IADL ####

data<-read_xlsx(paste0(dropbox, out_DS ,"ICI-Covid_Figure2_Restrictions_IADL.xlsx"))
data <- as.data.frame(data)

#Transpose
data <- t(data)
data <- as.data.frame(data)

#Keep proportion being help with a given task
data <- data %>%
  slice(3:3)


colnames(data) <- c("IADL: move around", "IADL: manage administrative tasks", "IADL: go out of the institution",
                    "IADL: manage transportation", "IADL: find one's way", 
                    "IADL: use phone")

## add 2 lines to the dataframe: the max and min of each topic to show on the plot
data <- rbind(rep(1,6) , rep(0,6) , data)

#Convert to numeric values
data = data %>% mutate_all(as.numeric)

## Export the radar chart
png(filename = paste0(dropbox, out_Fig, "ICI-Covid_Figure2_Restrictions_IADL.png"))

radarchart( data  , axistype=1, 
            
            #custom polygon
            pcol=rgb(0.5,0.5,0.5,1) , pfcol=rgb(0.5,0.5,0.5,0.5) , plwd=4 , 
            
            #custom the grid
            cglcol="grey", cglty=1, axislabcol="grey", cglwd=0.8,
            
            #custom labels
            vlcex=1.4
)

dev.off()


#### Spider charts: being helped with ADL or IADL ####
#####################################################

### Entire sample ###

data<-read_xlsx(paste0(dropbox, out_DS ,"ICI-Covid_Figure4_Tasks_All.xlsx"))
data <- as.data.frame(data)

#Transpose
data <- t(data)
data <- as.data.frame(data)

#Keep proportion being help with a given task
data <- data %>%
  slice(3:3)

#Rename column 
colnames(data) <- c("ADL: groom or dress", "ADL: cut food and eat","ADL: use toilets","ADL/IADL: transfer and move around",
                    "IADL: administrative tasks",  "IADL: domestic chores","IADL: prepare meals" , 
                    "IADL: do grocery" ,"IADL: take medication", "IADL : go out"
                    ,"IADL: manage transportation","IADL: find way outside", "IADL: use phone")

## add 2 lines to the dataframe: the max and min of each topic to show on the plot
data <- rbind(rep(1,13) , rep(0,13) , data)

#Convert to numeric values
data = data %>% mutate_all(as.numeric)

## Export the radar chart
png(filename = paste0(dropbox, out_Fig, "ICI-Covid_Figure4_Tasks_All.png"))

radarchart( data  , axistype=1, 
            
            #custom polygon
            pcol=rgb(0.5,0.5,0.5,1) , pfcol=rgb(0.5,0.5,0.5,0.5) , plwd=4 , 
            
            #custom the grid
            cglcol="grey", cglty=1, axislabcol="grey", cglwd=0.8,
            
            #custom labels
            vlcex=1
)

dev.off()

  
### Women ###

data<-read_xlsx(paste0(dropbox, out_DS ,"ICI-Covid_Figure4_Tasks_a.Women.xlsx"))
data <- as.data.frame(data)
  
#Transpose
data <- t(data)
data <- as.data.frame(data)
  
#Keep proportion being help with a given task
data <- data %>%
 slice(3:3)
  
#Rename column 
colnames(data) <- c("ADL: groom or dress", "ADL: cut food and eat","ADL: use toilets","ADL/IADL: transfer and move around",
                      "IADL: administrative tasks",  "IADL: domestic chores","IADL: prepare meals" , 
                      "IADL: do grocery" ,"IADL: take medication", "IADL : go out"
                      ,"IADL: manage transportation","IADL: find way outside", "IADL: use phone")
  
## add 2 lines to the dataframe: the max and min of each topic to show on the plot
data <- rbind(rep(1,13) , rep(0,13) , data)

#Convert to numeric values
data = data %>% mutate_all(as.numeric)
  
## Export the radar chart
png(filename = paste0(dropbox, out_Fig, "ICI-Covid_Figure4_Tasks_a.Women.png"))
  
radarchart( data  , axistype=1, 
              
          #custom polygon
          pcol=rgb(0.5,0.5,0.5,1) , pfcol=rgb(0.5,0.5,0.5,0.5) , plwd=4 , 
              
          #custom the grid
          cglcol="grey", cglty=1, axislabcol="grey", cglwd=0.8,
              
          #custom labels
          vlcex=1
)
  
dev.off()


### Men ###

data<-read_xlsx(paste0(dropbox, out_DS ,"ICI-Covid_Figure4_Tasks_b.Men.xlsx"))
data <- as.data.frame(data)

#Transpose
data <- t(data)
data <- as.data.frame(data)

#Keep proportion being help with a given task
data <- data %>%
  slice(3:3)

#Rename column 
colnames(data) <- c("ADL: groom or dress", "ADL: cut food and eat","ADL: use toilets","ADL/IADL: transfer and move around",
                    "IADL: administrative tasks",  "IADL: domestic chores","IADL: prepare meals" , 
                    "IADL: do grocery" ,"IADL: take medication", "IADL : go out"
                    ,"IADL: manage transportation","IADL: find way outside", "IADL: use phone")

## add 2 lines to the dataframe: the max and min of each topic to show on the plot
data <- rbind(rep(1,13) , rep(0,13) , data)

#Convert to numeric values
data = data %>% mutate_all(as.numeric)

## Export the radar chart
png(filename = paste0(dropbox, out_Fig, "ICI-Covid_Figure4_Tasks_b.Men.png"))

radarchart( data  , axistype=1, 
            
            #custom polygon
            pcol=rgb(0.5,0.5,0.5,1) , pfcol=rgb(0.5,0.5,0.5,0.5) , plwd=4 , 
            
            #custom the grid
            cglcol="grey", cglty=1, axislabcol="grey", cglwd=0.8,
            
            #custom labels
            vlcex=1
)

dev.off()



