#******************************************************************************
#
# Project ICI-Covid
#
# Obj: Statistics to output Venn diagramm
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 02/10/2020
#
#******************************************************************************


#### Packages for the program ####

# NB : for first run, need to do "install.packages(NAMEOFTHEPACKAGE)" first
# Then, run library(PACKAGE) at each opening of R
## Packages for the program
library(survey)
library(questionr) 

# Should run 0.Data.R beforehand

aidentfi_c<-seniors$aidentfi_c
aidentsou_c<-seniors$aidentsou_c
poids_senior<-seniors$poids_senior

# Test
tw1=wtd.table(aideproche_v2, weights=poids_senior,normwt=T)
prop.table(tw1)

# Variables of interest: aideproche_v2 / aidentfi_c / aidentsou_c
type <- aideproche_v2 + 2*aidentfi_c + 4*aidentsou_c

  # 0 = no help
  # 1 = help for ADL/IADL
  # 2 = financial support
  # 3 = ADL/IADL + financial
  # 4 = moral support
  # 5 = moral + ADL/IADL
  # 6 = moral + finanical
  # 7 = ADL/IADL + financial + moral

tw2=wtd.table(type, weights=poids_senior)
prop.table(tw2)

broad_care <- subset(seniors, type !=0)

r1  <- broad_care$raaident_r1
r2  <- broad_care$raaident_r2
r3  <- broad_care$raaident_r3
r4  <- broad_care$raaident_r4
r5  <- broad_care$raaident_r5
r6  <- broad_care$raaident_r6
r7  <- broad_care$raaident_r7
r8  <- broad_care$raaident_r8
r9  <- broad_care$raaident_r9
r10 <- broad_care$raaident_r10
r11 <- broad_care$raaident_r11
r12 <- broad_care$raaident_r12
r13 <- broad_care$raaident_r13


aideproche_v2 <- ifelse(r1== 1 | r2== 1 | r3== 1 | r4== 1 | r5== 1 |
                          r6== 1 | r7== 1 | r8== 1 | r9== 1 | r10== 1 |
                          r11== 1 | r12== 1 | r13== 1, 1,0)


aidentfi_c  <- broad_care$aidentfi_c
aidentsou_c  <- broad_care$aidentsou_c

tw_help=wtd.table(aideproche_v2, weights=poids_senior,normwt=T)
prop.table(tw_help)

tw_fin=wtd.table(aidentfi_c, weights=poids_senior,normwt=T)
prop.table(tw_fin)

tw_sou=wtd.table(aidentsou_c, weights=poids_senior,normwt=T)
prop.table(tw_sou)

type <- aideproche_v2 + 2*aidentfi_c + 4*aidentsou_c

tw2=wtd.table(type, weights=poids_senior,normwt=T)
prop.table(tw2)